@@ -6,6 +6,7 @@ from suanpan.utils import tools
 
 
 class APP:
+
     def __init__(self):
         self.func = None
 
@@ -17,8 +18,18 @@ class APP:
             result = self.func(context)
             if result is not None:
                 data = tools.formatOutput(result)
-                print(data)
                 stream.sendMessage(data, context)
 
+    def send(self, result, context):
+        data = tools.formatOutput(result)
+        stream.sendMessage(data, context)
+
+    def contextGen(self):
+        return stream.generateMessage()
+
+    def sendWithoutContext(self, result):
+        context = self.contextGen()
+        self.send(result, context)
+
 
 app = APP()
