@@ -39,10 +39,8 @@ class Stream:
     def generateRequestId(self):
         return uuid.uuid4().hex
 
-    def generateMessage(self, **kwargs):
-        message = {}
-        message.update({}, **kwargs)
-        message["id"] = self.generateRequestId()
+    def generateMessage(self):
+        message = Context(extra={}, request_id=self.generateRequestId())
         return message
 
     def sendMessage(self, data, message):
